==> WHLX_CMS-0.03alpha.zip: whlx/script/crypt.php <==
<?php
// 
// WHLX CMS - crypt.php
// 
// 20040410 - 0.00 alpha
// 




error_reporting( E_ERROR | E_PARSE );


// './path.ini' を読み込み, 設定ファイルやライブラリ・ファイルの相対パスを取得します. 
// './path.ini' はスクリプトと同じディレクトリに置く必要があります. 
$whlx =  parse_ini_file( './path.ini',      true );    

include_once  $whlx[ 'directory' ][ 'library' ].  './utilities.php';
include_once  $whlx[ 'directory' ][ 'library' ].  './formdata.php';
include_once  $whlx[ 'directory' ][ 'library' ].  './domxml.php';

// class WHLX_Formdata は './utilities.php' の中で記述されている補助クラスです. 
// Formdata::form()   でスクリプトに送信された フォーム・データ を取得できます. 返値は配列になります. 
// Formdata::header() でスクリプトに送信された HTTPリクエスト   を取得できます. 返値は配列になります. 
$formclass =  new WHLX_Formdata();     
$form      =  $formclass->form  ();    
$header    =  $formclass->header();    

$seed  =  'pw'; //    $header[ '_POST' ][ 'seed' ];
$key   =  $header[ '_POST' ][ 'password' ];
$crypt =  crypt( $key, $seed );

$error   =  0;

$message =  
	"\n".    
	'		<div class="post_base"> '.                                                                                                               "\n".    
	'			<label class="post_label"> Seed  <input class="post_input" type="text" readonly="" value="'.  $seed.   '" /> </label> <br /> '.  "\n".    
	'			<label class="post_label"> Key   <input class="post_input" type="text" readonly="" value="'.  $key.    '" /> </label> <br /> '.  "\n".    
	'			<label class="post_label"> Crypt <input class="post_input" type="text" readonly="" value="'.  $crypt.  '" /> </label> <br /> '.  "\n".    
	'		</div> '.                                                                                                                                "\n";    

$others  =  
	"\n".    
	'		<title> WHLX CMS - パスワード生成スクリプト </title> '.  "\n".    
	'		<form password="yes"> '.                                 "\n".    
	'			<action >./crypt.php</action > '.                "\n".    
	'		</form> '.                                               "\n";    

$output  =  WHLX_PostingResponse( $error, $message, $others, './_script.xsl' );

WHLX_ResponseHeader_XML ();
echo  $output;


exit;




?>

==> WHLX_CMS-0.05alpha.zip: whlx/script/crypt.php <==
<?php
// 
// WHLX CMS - crypt.php
// 
// 20040410 - 0.00 alpha
// 20040413 - 0.06 alpha    whlx.ini の仕様変更に伴う少々の変更. 
// 




error_reporting( E_ERROR | E_PARSE );


// './path.ini' を読み込み, 設定ファイルやライブラリ・ファイルの相対パスを取得します. 
// './path.ini' はスクリプトと同じディレクトリに置く必要があります. 
$whlx =  parse_ini_file( './path.ini',      true );    
$whlx =  array_merge( $whlx, parse_ini_file( $whlx[ 'directory' ][ 'hidden' ].  './whlx.ini', true ) );    

include_once  $whlx[ 'directory' ][ 'library' ].  './utilities.php';
include_once  $whlx[ 'directory' ][ 'library' ].  './formdata.php';
include_once  $whlx[ 'directory' ][ 'library' ].  './domxml.php';

// class WHLX_Formdata は './utilities.php' の中で記述されている補助クラスです. 
// Formdata::form()   でスクリプトに送信された フォーム・データ を取得できます. 返値は配列になります. 
// Formdata::header() でスクリプトに送信された HTTPリクエスト   を取得できます. 返値は配列になります. 
$formclass =  new WHLX_Formdata();     
$form      =  $formclass->form  ();    
$header    =  $formclass->header();    

$seed   =  'pw'; //    $header[ '_POST' ][ 'seed' ];
$key    =  $header[ '_POST' ][ 'password' ];
$crypt  =  crypt( $key, $seed );
$action =  $whlx[ 'script' ][ 'crypt' ];

$error   =  0;

$message =  
	"\n".    
	'		<div class="post_base"> '.                                                                                                               "\n".    
	'			<label class="post_label"> Seed  <input class="post_input" type="text" readonly="" value="'.  $seed.   '" /> </label> <br /> '.  "\n".    
	'			<label class="post_label"> Key   <input class="post_input" type="text" readonly="" value="'.  $key.    '" /> </label> <br /> '.  "\n".    
	'			<label class="post_label"> Crypt <input class="post_input" type="text" readonly="" value="'.  $crypt.  '" /> </label> <br /> '.  "\n".    
	'		</div> '.                                                                                                                                "\n";    

$others  =  
	"\n".    
	'		<title> WHLX CMS - パスワード生成スクリプト </title> '.  "\n".    
	'		<form password="yes"> '.                                 "\n".    
	'			<action >'.  $action.  '</action > '.            "\n".    
	'		</form> '.                                               "\n";    

$output  =  WHLX_PostingResponse( $error, $message, $others, './_script.xsl' );

WHLX_ResponseHeader_XML ();
echo  $output;


exit;




?>
